; Rotinas de suporte

;-----
; Le um byte da BIOS
; Entrada: HL: Endereco a ser lido
; Muda: AF
;-----
READBIOS:
        PUSH    BC
        PUSH    DE
        LD      A,(EXPTBL)      ; Slot da MainRom
        CALL    RDSLT           ; Chama rotina
        POP     DE
        POP     BC
        RET                     ; Volta


;-----
; Salva registros IX e IY na pilha (nesta ordem)
;-----
SAVEEXTRAREGS:
	EX	AF,AF'		; Troca AF por AF'
        POP     AF		; Le end. de retorno em AF'
        PUSH    IX		; Salva IX na pilha
        PUSH    IY		; Salva IY na pilha
        PUSH    AF		; Coloca AF' (end de ret) na pilha
        EX      AF,AF'		; Troca AF' por AF
        RET			; Retorna...

;-----
; Salva na pilha os registros AF,BC,DE e HL (nesta ordem)
;-----
SAVECOMMONREGS:
	EX	AF,AF'		; Troca AF por AF'
	POP	AF		; Le end de ret em AF'
	EX	AF,AF'		; Troca AF' por AF
	PUSH    AF		; Salva AF na pilha
	PUSH    BC		; Salva BC na pilha
	PUSH    DE		; Salva DE na pilha
	PUSH    HL		; Salva HL na pilha
	EX      AF,AF'		; Troca AF por AF'
	PUSH    AF		; Coloca AF' (end de ret) na pilha
	EX      AF,AF'		; Troca AF' por AF
	RET			; Retorna...


;-----
; Retira da pilha registros salvos com SAVEEXTRAREGS
;-----
LOADEXTRAREGS:
	EX	AF,AF'		; Troca AF por AF'
	POP	AF		; Pega endereco de Retorno em AF'
	POP	IY		; Le IY da pilha
	POP	IX		; Le IX da pilha
	PUSH	AF		; Coloca AF'(end de retorno) na pilha
	EX	AF,AF'		; Troca AF' por AF.
	RET			; Retorna...

;-----
; Retira da pilha registros salvos com SAVECOMMONREGS
;-----
LOADCOMMONREGS:
        EX      AF,AF'		; Salva troca AF por AF'
        POP     AF		; Recupera end de retorno em AF'
        EX      AF,AF'		; Troca AF'por AF
        POP     HL		; Le HL da pilha
        POP     DE		; Le DE da pilha
        POP     BC		; Le BC da pilha
        POP     AF		; Le AF da pilha
        EX      AF,AF'		; Troca AF por AF'
        PUSH    AF		; Coloca AF'(end de retorno) na pilha
        EX      AF,AF'		; Troca AF' por AF
        RET			; Retorna...

;-----
; Esta funcao imprime uma mensagem pelo BDOS
; Entrada: DE - ponteiro para mensagem terminada por $
;-----
PRTMSGBDOS:
        LD      C,STROUT        ; Carrega funcao em C
        CALL    BDOS            ; Chama BDOS
        RET                     ; Retorna...

;-----
; Esta funcao chama uma funcao da BIOS
; Entrada: IX - ponteiro para funcao da BIOS
;-----
CALLBIOS:
	PUSH	IX
	PUSH	IY
        LD      IY,(EXPTBL-1)   ; Slot da MainRom
        CALL    CALSLT          ; Chama rotina
	POP	IY
	POP	IX
        RET                     ; Volta...

;-----
; Esta funcao chama uma funcao da SubRom
; Entrada: IX - ponteiro para funcao da SubRom
;-----
CALLSUB:
	PUSH	IX
	PUSH	IY
        LD      IY,(EXBRSA-1)   ; Slot da SubRom
        CALL    CALSLT          ; Chama rotina
	POP	IY
	POP	IX
        RET                     ; Volta...


;-----
; Esta funcao serve para gastar tempo
;-----
WAITSOME:
	PUSH	BC
	LD	B,255
WAITSOME2:
	PUSH	BC
	EXX
	POP	BC
	DJNZ	WAITSOME2
	POP	BC
	RET

;-----
; Esta rotina toca um beep
;-----
PLAYBEEP:
	CALL	SAVECOMMONREGS
	CALL	SAVEEXTRAREGS
	LD	IX,BEEP
	CALL	CALLBIOS
	CALL	LOADEXTRAREGS
	CALL	LOADCOMMONREGS
	RET



